( cd usr/bin ; rm -rf znew )
( cd usr/bin ; ln -sf ../../bin/znew znew )
( cd usr/bin ; rm -rf zmore )
( cd usr/bin ; ln -sf ../../bin/zmore zmore )
( cd usr/bin ; rm -rf zless )
( cd usr/bin ; ln -sf ../../bin/zless zless )
( cd usr/bin ; rm -rf zgrep )
( cd usr/bin ; ln -sf ../../bin/zgrep zgrep )
( cd usr/bin ; rm -rf zforce )
( cd usr/bin ; ln -sf ../../bin/zforce zforce )
( cd usr/bin ; rm -rf zfgrep )
( cd usr/bin ; ln -sf ../../bin/zfgrep zfgrep )
( cd usr/bin ; rm -rf zegrep )
( cd usr/bin ; ln -sf ../../bin/zegrep zegrep )
( cd usr/bin ; rm -rf zdiff )
( cd usr/bin ; ln -sf ../../bin/zdiff zdiff )
( cd usr/bin ; rm -rf zcmp )
( cd usr/bin ; ln -sf ../../bin/zcmp zcmp )
( cd usr/bin ; rm -rf zcat )
( cd usr/bin ; ln -sf ../../bin/zcat zcat )
( cd usr/bin ; rm -rf gzip )
( cd usr/bin ; ln -sf ../../bin/gzip gzip )
( cd usr/bin ; rm -rf gzexe )
( cd usr/bin ; ln -sf ../../bin/gzexe gzexe )
( cd usr/bin ; rm -rf gunzip )
( cd usr/bin ; ln -sf ../../bin/gunzip gunzip )
